@@ -3,10 +3,10 @@
 import sys
 
 from pathlib import Path
-from tempfile import TemporaryDirectory
 from typing import Any
 from typing import Dict
 from typing import List
+from typing import Union
 from unittest import mock
 
 import pandas as pd
@@ -46,6 +46,15 @@ def dataframe_2_fixture() -> pd.DataFrame:
     )
 
 
+@pytest.fixture(name="dataframe_global")
+def dataframe_global_fixture() -> pd.DataFrame:
+    """Create a DataFrameDisplay object."""
+    return pd.read_csv(
+        "https://github.com/Anselmoo/spectrafit/blob/"
+        "9cf51ce020925228be26468763466c7fd91fedf0/Examples/example_6_fit.csv?raw=true"
+    )
+
+
 @pytest.fixture(name="x_column")
 def x_column_fixture(dataframe: pd.DataFrame) -> str:
     """Create a x_column object."""
@@ -136,38 +145,62 @@ def export_report_fixture(
 
 @pytest.fixture(name="class_spectrafit")
 def class_spectrafit_fixture(
-    dataframe_2: pd.DataFrame, initial_model: List[Dict[str, Dict[str, Dict[str, Any]]]]
-) -> Dict[Any, Any]:
+    dataframe_2: pd.DataFrame,
+    initial_model: List[Dict[str, Dict[str, Dict[str, Any]]]],
+    tmp_path: Path,
+) -> Dict[str, Union[SpectraFitNotebook, Path]]:
     """Create a SpectraFitNotebook object."""
-    with TemporaryDirectory() as tmpdir:
-        _df = pd.DataFrame(data={"x": [1, 2, 3], "y": [1, 2, 3]})
-        sp = SpectraFitNotebook(
-            df=_df,
-            x_column="x",
-            y_column="y",
-            folder=str(tmpdir),
-            fname="test",
-        )
-        sp.df_fit = dataframe_2
-        sp.initial_model = initial_model
-        sp.df_pre = _df
-        sp.df_metric = _df
-        return {"sp": sp, "tmpdir": str(tmpdir)}
+    _df = pd.DataFrame(data={"x": [1, 2, 3], "y": [1, 2, 3]})
+    sp = SpectraFitNotebook(
+        df=_df,
+        x_column="x",
+        y_column="y",
+        folder=str(tmp_path),
+        fname="test",
+    )
+    sp.df_fit = dataframe_2
+    sp.initial_model = initial_model
+    sp.df_pre = _df
+    sp.df_metric = _df
+    return {"sp": sp, "tmpdir": tmp_path}
+
+
+@pytest.fixture(name="class_spectrafit_fit_global")
+def class_spectrafit_fixture_fit_global(
+    dataframe_global: pd.DataFrame,
+    initial_model: List[Dict[str, Dict[str, Dict[str, Any]]]],
+    tmp_path: Path,
+) -> Dict[str, Union[SpectraFitNotebook, Path]]:
+    """Create a SpectraFitNotebook object."""
+    dataframe_init = pd.read_csv(
+        "https://github.com/Anselmoo/spectrafit/blob/"
+        "9cf51ce020925228be26468763466c7fd91fedf0/Examples/data_global.csv?raw=true"
+    )
+
+    sp = SpectraFitNotebook(
+        df=dataframe_init,
+        x_column="energy",
+        y_column=["y_1", "y_2", "y_3"],
+        fname="test",
+        folder=str(tmp_path),
+    )
+    sp.df_fit = dataframe_global
+    sp.initial_model = initial_model
+    return {"sp": sp, "tmpdir": tmp_path}
 
 
 @pytest.fixture(name="class_spectrafit_fit")
 def class_spectrafit_fixture_fit(
-    dataframe: pd.DataFrame, x_column: str, y_column: str
+    dataframe: pd.DataFrame, x_column: str, y_column: str, tmp_path: Path
 ) -> SpectraFitNotebook:
     """Create a SpectraFitNotebook object."""
-    with TemporaryDirectory() as tmpdir:
-        return SpectraFitNotebook(
-            df=dataframe,
-            x_column=x_column,
-            y_column=y_column,
-            fname="test",
-            folder=str(tmpdir),
-        )
+    return SpectraFitNotebook(
+        df=dataframe,
+        x_column=x_column,
+        y_column=y_column,
+        fname="test",
+        folder=str(tmp_path),
+    )
 
 
 def test_dataframe_display(dataframe: pd.DataFrame) -> None:
@@ -228,6 +261,16 @@ class TestDataFramePlot:
             )
             mock_show.assert_called_once()
 
+    def test_dataframe_plot_global(self, dataframe_global: pd.DataFrame) -> None:
+        """Test global plot."""
+        pp = DataFramePlot()
+        with mock.patch(__plotly_io_show__) as mock_show:
+            pp.plot_global_fit(
+                args_plot=PlotAPI(x="Energy", y="Intensity", title="Test"),
+                df=dataframe_global,
+            )
+            mock_show.assert_called()
+
 
 def test_dataframe_display_all(dataframe: pd.DataFrame) -> None:
     """Test the DataFrameDisplay class."""
@@ -245,37 +288,35 @@ def test_dataframe_display_all(dataframe: pd.DataFrame) -> None:
 class TestExportResults:
     """Test of the Export Results class."""
 
-    def test_export_df(self, dataframe: pd.DataFrame) -> None:
+    def test_export_df(self, dataframe: pd.DataFrame, tmp_path: Path) -> None:
         """Test the export function."""
-        with TemporaryDirectory() as tmpdir:
-            fname = "test"
-            prefix = "test"
-            suffix = "csv"
-            folder = str(tmpdir)
-            ExportResults().export_df(
-                df=dataframe,
-                args=FnameAPI(fname=fname, prefix=prefix, suffix=suffix, folder=folder),
-            )
-            assert Path(folder).joinpath(f"{prefix}_{fname}.{suffix}").exists()
+        fname = "test"
+        prefix = "test"
+        suffix = "csv"
+        folder = str(tmp_path)
+        ExportResults().export_df(
+            df=dataframe,
+            args=FnameAPI(fname=fname, prefix=prefix, suffix=suffix, folder=folder),
+        )
+        assert Path(folder).joinpath(f"{prefix}_{fname}.{suffix}").exists()
 
-    def test_export_report(self, dataframe: pd.DataFrame) -> None:
+    def test_export_report(self, dataframe: pd.DataFrame, tmp_path: Path) -> None:
         """Test the export function."""
-        with TemporaryDirectory() as tmpdir:
-            fname = "test"
-            prefix = "test"
-            suffix = "lock"
-            folder = str(tmpdir)
-            ExportResults().export_report(
-                report=dataframe.to_dict(orient="list"),
-                args=FnameAPI(fname=fname, prefix=prefix, suffix=suffix, folder=folder),
-            )
-            assert Path(folder).joinpath(f"{prefix}_{fname}.{suffix}").exists()
+        fname = "test"
+        prefix = "test"
+        suffix = "lock"
+        folder = str(tmp_path)
+        ExportResults().export_report(
+            report=dataframe.to_dict(orient="list"),
+            args=FnameAPI(fname=fname, prefix=prefix, suffix=suffix, folder=folder),
+        )
+        assert Path(folder).joinpath(f"{prefix}_{fname}.{suffix}").exists()
 
     def test_static_fname(self) -> None:
         """Test the static function of generating PathPosixs."""
-        assert isinstance(ExportResults.fname2Path(fname="test", suffix="csv"), Path)
+        assert isinstance(ExportResults.fname2path(fname="test", suffix="csv"), Path)
         assert isinstance(
-            ExportResults.fname2Path(
+            ExportResults.fname2path(
                 fname="test", suffix="csv", folder="tmp", prefix="prefix"
             ),
             Path,
@@ -353,19 +394,19 @@ class TestSpectraFitNotebook:
         class_spectrafit["sp"].export_df_org
         class_spectrafit["sp"].export_df_pre
         class_spectrafit["sp"].export_df_metric
-        assert ExportResults.fname2Path(
+        assert ExportResults.fname2path(
             folder=class_spectrafit["tmpdir"], fname="test", prefix="act", suffix="csv"
         ).exists()
-        assert ExportResults.fname2Path(
+        assert ExportResults.fname2path(
             folder=class_spectrafit["tmpdir"], fname="test", prefix="fit", suffix="csv"
         ).exists()
-        assert ExportResults.fname2Path(
+        assert ExportResults.fname2path(
             folder=class_spectrafit["tmpdir"], fname="test", prefix="org", suffix="csv"
         ).exists()
-        assert ExportResults.fname2Path(
+        assert ExportResults.fname2path(
             folder=class_spectrafit["tmpdir"], fname="test", prefix="pre", suffix="csv"
         ).exists()
-        assert ExportResults.fname2Path(
+        assert ExportResults.fname2path(
             folder=class_spectrafit["tmpdir"],
             fname="test",
             prefix="metric",
@@ -413,9 +454,20 @@ class TestSpectraFitNotebook:
     ) -> None:
         """Test the plot function."""
         with mock.patch(__plotly_io_show__) as mock_show:
-            class_spectrafit["sp"].plot_fit_df
+            class_spectrafit["sp"].plot_fit_df()
             mock_show.assert_called_once()
 
+    @pytest.mark.skipif(sys.platform == "win32", reason="does not run on windows")
+    @pytest.mark.webtest
+    def test_plot_global(
+        self,
+        class_spectrafit_fit_global: Dict[Any, Any],
+    ) -> None:
+        """Test the plot function for global fitting routine."""
+        with mock.patch(__plotly_io_show__) as mock_show:
+            class_spectrafit_fit_global["sp"].plot_fit_df()
+            mock_show.assert_called()
+
     def test_display(
         self,
         class_spectrafit: Dict[Any, Any],
@@ -440,7 +492,7 @@ class TestSpectraFitNotebook:
         sp.df_fit = dataframe_2
         sp.generate_report
 
-        assert ExportResults.fname2Path(
+        assert ExportResults.fname2path(
             folder=sp.export_args_out.folder,
             fname="test",
             suffix="lock",
@@ -494,6 +546,7 @@ class TestSpectraFitNotebook:
                 show_plot=False,
                 show_df=True,
                 show_metric=True,
+                show_peaks=True,
                 conf_interval=True,
             )
             mock_show.assert_called_once()
@@ -512,11 +565,32 @@ class TestSpectraFitNotebook:
                 show_plot=False,
                 show_df=True,
                 show_metric=True,
+                show_peaks=True,
                 conf_interval={},
             )
 
             mock_show.assert_called_once()
 
+    def test_conv_no(
+        self,
+        class_spectrafit_fit: SpectraFitNotebook,
+        initial_model: List[Dict[str, Dict[str, Dict[str, Any]]]],
+    ) -> None:
+        """Test conf interval via bool for false."""
+        sp = class_spectrafit_fit
+
+        with mock.patch(__plotly_io_show__) as mock_show:
+            sp.solver_model(
+                initial_model=initial_model,
+                show_plot=False,
+                show_df=True,
+                show_metric=True,
+                show_peaks=True,
+                conf_interval=False,
+            )
+
+            mock_show.assert_called_once()
+
     def test_display_current_df(
         self,
         class_spectrafit_fit: SpectraFitNotebook,
@@ -529,3 +603,20 @@ class TestSpectraFitNotebook:
         sp.display_original_df()
         sp.display_preprocessed_df()
         sp.display_fit_df()
+
+    def test_confidence_interval_false_expot(
+        self,
+        class_spectrafit_fit: SpectraFitNotebook,
+        initial_model: List[Dict[str, Dict[str, Dict[str, Any]]]],
+    ) -> None:
+        """Test the confidence interval function."""
+        sp = class_spectrafit_fit
+        sp.solver_model(
+            initial_model=initial_model,
+            show_plot=False,
+            show_df=False,
+            show_metric=False,
+            show_peaks=False,
+            conf_interval=False,
+        )
+        sp.generate_report
